@@ -42,7 +42,10 @@ class ClientConfig(object):
 
     APP_NAME = 'Not So TUF'
     COMPANY_NAME = 'Digital Sapphire'
-    UPDATE_URL = 'https://s3-us-west-1.amazonaws.com/not-so-tuf/'
+    if os.path.exists(os.path.join(cwd_, 'debug.txt')):
+        UPDATE_URL = 'http://localhost:8000'
+    else:
+        UPDATE_URL = 'https://s3-us-west-1.amazonaws.com/not-so-tuf/'
     PUBLIC_KEY = (20108396243319911582598596115745239989885400175227707389521317729033635840299100098853596321405101734772502480347809316412443410341343456658819303295609568503560590213458417406289673047067061470663007934259038584291430372736269382548148746125115340848958555445285186466072484498307728141378225246810783728748418077590393647140601680370572187285974144350446751248280469500607629543851685059723717251232927793777304500418725557133877789415933828850137864470404672129358052555306788192180685116519389020808027326496485426387958512948345437474857267466312681047488723469520344767349264331943557545878009395265009303779143L, 65537L)
 
 
