@@ -68,8 +68,8 @@ class Settings(CommonLogic, Menu):
         self.display_msg('-->235 ')
         self.display_msg('-->513')
         self.display_msg('Then press Enter')
-        print_(('1. App Name\n2. Dev Data Dir\n3. Update Url\n4. Update SSH '
-               'settings\n5. Update S3 settings\n'))
+        print_(('1. App Name\n2. Company Name\n3. Dev Data Dir\n4. '
+               'Update Url\n5. Update SSH settings\n6. Update S3 settings\n'))
         answers = input_('-->')
 
         self.display_menu_header('Updating Settings')
@@ -78,16 +78,23 @@ class Settings(CommonLogic, Menu):
                                           default=self.config.APP_NAME)
             self.config.APP_NAME = app_name
         if '2' in answers:
+            if not hasattr(self.config, 'COMPANY_NAME'):
+                self.config.COMPANY_NAME = None
+            company_name = get_correct_answer('Enter Company Name',
+                                              default=self.config.COMPANY_NAME)
+            self.config.COMPANY_NAME = company_name
+
+        if '3' in answers:
             data_dir = get_correct_answer('Enter directory to store work '
                                           'files',
                                           default=self.config.DEV_DATA_DIR)
             self.config.DEV_DATA_DIR = _directory_fixer(data_dir)
-        if '3' in answers:
+        if '4' in answers:
             url = get_correct_answer('Enter new update url',
                                      default=self.config.UPDATE_URL)
             self.config.UPDATE_URL = url
 
-        if '4' in answers:
+        if '5' in answers:
             remote_dir = get_correct_answer('Enter remote path',
                                             default=self.config.REMOTE_DIR)
             ssh_host = get_correct_answer('Enter ssh host',
@@ -104,7 +111,7 @@ class Settings(CommonLogic, Menu):
             self.config.SSH_USERNAME = ssh_username
             self.config.SSH_KEY_PATH = _directory_fixer(ssh_key_path)
 
-        if '5' in answers:
+        if '6' in answers:
             self.config.ACCESS_KEY_ID = get_correct_answer('Enter access key',
                                                            required=True)
             self.config.SECRET_ACCESS_KEY = get_correct_answer('Enter secret',
