@@ -22,7 +22,6 @@
 
 from base64 import urlsafe_b64encode
 import getpass
-import hashlib
 import logging
 import os
 import sys
@@ -33,6 +32,7 @@ from cryptography.hazmat.backends import openssl
 
 from not_so_tuf.compat import input_
 from not_so_tuf.exceptions import FileCryptError
+from not_so_tuf.utils import cwd_, pbkdf2_hex
 
 
 log = logging.getLogger(__name__)
@@ -62,9 +62,28 @@ class FileCrypt(object):
         self.password_timer = 0
         self.password_max_tries = max_tries
         self.passwrod_timeout = password_timeout
+        self.salt_file = os.path.join(cwd_, 'salt.data')
         self.test = False
+        self.salt = None
         self.new_file(filename)
 
+    def gen_pass(self, x):
+        if self.test is False:
+            if not os.path.exists(self.salt_file):
+                salt = os.urandom(16)
+                with open(self.salt_file, 'w') as f:
+                    f.write(salt)
+
+            with open(self.salt_file, 'r') as f:
+                salt = f.read()
+        else:
+            salt = self.salt
+
+        key = pbkdf2_hex(x, salt, keylen=16)
+        new_key = urlsafe_b64encode(key)
+
+        return new_key
+
     def new_file(self, filename=None):
         """Adds filename internally to be used for encryption and
         decryption. Also adds .enc to filename to be used  as
@@ -151,12 +170,6 @@ class FileCrypt(object):
             log.warning('You entered to many wrong passwords.')
             sys.exit(0)
 
-    @staticmethod
-    def gen_pass(x):
-        big_key = hashlib.sha256(x).hexdigest()
-        key = big_key[:32]
-        return urlsafe_b64encode(key)
-
     def _set_filenames(self, filename):
         # Helper function to correctly set filename and
         # enc_filename instance attributes
@@ -172,7 +185,7 @@ class FileCrypt(object):
         # Gets user password without echoing to the console
         log.debug('Getting user password')
         pass_ = getpass.getpass('Enter password:\n-->')
-        self.password = FileCrypt.gen_pass(pass_)
+        self.password = self.gen_pass(pass_)
         log.debug('Got you pass')
         self._update_timer()
 
