@@ -191,10 +191,24 @@ class KeyHandler(object):
             return
 
         self.fc.new_file(privkey)
-        self.fc.decrypt()
-        with open(privkey) as pk:
-            self.privkey = Crypto.PublicKey.RSA.importKey(pk.read())
-        self.fc.encrypt()
+        if self.test is False:
+            try:
+                self.fc.decrypt()
+            except:
+                log.warning('Nothing to decrypt')
+
+        if os.path.exists(privkey):
+            try:
+                with open(privkey) as pk:
+                    self.privkey = Crypto.PublicKey.RSA.importKey(pk.read())
+            except Exception as e:
+                log.error(e, exc_info=True)
+                raise KeyHandlerError('Invalid private key')
+        else:
+            raise KeyHandlerError('Private key not found')
+
+        if self.test is False:
+            self.fc.encrypt()
 
     def _add_sig(self):
         # Adding new signature to version file
