@@ -247,12 +247,10 @@ class PackageHandler(object):
 
             # Converting info to version file format
             info = {'file_hash': file_hash,
-                    'url': self.update_url + p['real_name'],
                     'filename': filename}
             if patch_name and patch_hash:
                 info['patch_name'] = patch_name
                 info['patch_hash'] = patch_hash
-                info['patch_url'] = self.update_url + patch_name
 
             log.debug('json version {}'.format(self.json_data['updates']
                       [name].get(version, None)))
@@ -263,15 +261,6 @@ class PackageHandler(object):
             if self.json_data['updates'][name].get(version, None) is None:
                 log.debug('Adding new version to file')
 
-                # Preforming check for y_data because this could be a new
-                # version file not requiring legacy support Also allowing
-                # up to 8 overlapping updates to ease transition :)
-                if len(versions) <= 8 and \
-                        self.json_data.get('y_data', None) is not None:
-                    self.json_data['y_data'][name][version] = {}
-                    temp = self.json_data['y_data'][name]
-                    temp[version][p['platform']] = info
-
                 # Getting ready to throw a new version in there
                 self.json_data['updates'][name][version] = {}
                 if self.json_data['updates'][name][version].get('platform',
